==> anarchism_15.0.orig.tar.gz: afaq-15.0/markdown/append135.md <==
# 5 Will privatising "the commons" increase liberty?

"Anarcho"-capitalists aim for a situation in which _"no land areas, no square
footage in the world shall remain 'public,'"_ in other words **everything**
will be _"privatised."_ [Murray Rothbard, **Nations by Consent**, p. 84] They
claim that privatising "the commons" (e.g. roads, parks, etc.) which are now
freely available to all will increase liberty. Is this true? We have shown
before why the claim that privatisation can protect the environment is highly
implausible (see section [E.2](secE2.html)). Here we will concern ourselves
with private ownership of commonly used "property" which we all take for
granted and pay for with taxes.

Its clear from even a brief consideration of a hypothetical society based on
"privatised" roads (as suggested by Murray Rothbard in **For a New Liberty**,
pp. 202-203 and David Friedman in **The Machinery of Freedom**, pp. 98-101)
that the only increase of liberty will be for the ruling elite. As
"anarcho"-capitalism is based on paying for what one uses, privatisation of
roads would require some method of tracking individuals to ensure that they
pay for the roads they use. In the UK, for example, during the 1980s the
British Tory government looked into the idea of toll-based motorways.
Obviously having toll-booths on motorways would hinder their use and restrict
"freedom," and so they came up with the idea of tracking cars by satellite.
Every vehicle would have a tracking device installed in it and a satellite
would record where people went and which roads they used. They would then be
sent a bill or have their bank balances debited based on this information (in
the fascist city-state/company town of Singapore such a scheme **has** been
introduced).

If we extrapolate from this example to a system of **fully** privatised
"commons," it would clearly require all individuals to have tracking devices
on them so they could be properly billed for use of roads, pavements, etc.
Obviously being tracked by private firms would be a serious threat to
individual liberty. Another, less costly, option would be for private guards
to randomly stop and question car-owners and individuals to make sure they had
paid for the use of the road or pavement in question. "Parasites" would be
arrested and fined or locked up. Again, however, being stopped and questioned
by uniformed individuals has more in common with police states than liberty.
Toll-boothing **every** street would be highly unfeasible due to the costs
involved and difficulties for use that it implies. Thus the idea of
privatising roads and charging drivers to gain access seems impractical at
best and distinctly freedom endangering if implemented at worse.

Of course, the option of owners letting users have free access to the roads
and pavements they construct and run would be difficult for a profit-based
company. No one could make a profit in that case. If companies paid to
construct roads for their customers/employees to use, they would be
financially hindered in competition with other companies that did not, and
thus would be unlikely to do so. If they restricted use purely to their own
customers, the tracking problem appears again.

Some may object that this picture of extensive surveillance of individuals
would not occur or be impossible. However, Murray Rothbard (in a slightly
different context) argued that technology would be available to collate
information about individuals. He argued that _"[i]t should be pointed out
that modern technology makes even more feasible the collection and
dissemination of information about people's credit ratings and records of
keeping or violating their contracts or arbitration agreements. Presumably, an
anarchist [sic!] society would see the expansion of this sort of dissemination
of data."_ [_"Society Without A State"_, in **Nomos XIX**, Pennock and Chapman
(eds.), p. 199] So, perhaps, with the total privatisation of society we would
also see the rise of private Big Brothers, collecting information about
individuals for use by property owners. The example of the **Economic League**
(a British company who provided the "service" of tracking the political
affiliations and activities of workers for employers) springs to mind.

And, of course, these privatisation suggestions ignore differences in income
and market power. If, for example, variable pricing is used to discourage road
use at times of peak demand (to eliminate traffic jams at rush-hour) as is
suggested both by Murray Rothbard and David Friedman, then the rich will have
far more "freedom" to travel than the rest of the population. And we may even
see people having to go into debt just to get to work or move to look for
work.

Which raises another problem with notion of total privatisation, the problem
that it implies the end of freedom of travel. Unless you get permission or
(and this seems more likely) pay for access, you will not be able to travel
**anywhere.** As Rothbard **himself** makes clear, "anarcho"-capitalism means
the end of the right to roam or even travel. He states that _"it became clear
to me that a totally privatised country would not have open borders at all. If
every piece of land in a country were owned . . . no immigrant could enter
there unless invited to enter and allowed to rent, or purchase, property."_
[**Nations by Consent**, p. 84] What happens to those who cannot **afford** to
pay for access is not addressed (perhaps, being unable to exit a given
capitalist's land they will become bonded labourers? Or be imprisoned and used
to undercut workers' wages via prison labour? Perhaps they will just be shot
as trespassers? Who can tell?). Nor is it addressed how this situation
actually **increases** freedom. For Rothbard, a _"totally privatised country
would be as closed as the particular inhabitants and property owners [**not**
the same thing, we must point out] desire. It seems clear, then, that the
regime of open borders that exists **de facto** in the US really amounts to a
compulsory opening by the central state. . . and does not genuinely reflect
the wishes of the proprietors."_ [**Op. Cit.**, p. 85] Of course, the wishes
of **non**-proprietors (the vast majority) do not matter in the slightest.
Thus, it is clear, that with the privatisation of "the commons" the right to
roam, to travel, would become a privilege, subject to the laws and rules of
the property owners. This can hardly be said to **increase** freedom for
anyone bar the capitalist class.

Rothbard acknowledges that _"in a fully privatised world, access rights would
obviously be a crucial part of land ownership."_ [**Nations by Consent**, p.
86] Given that there is no free lunch, we can imagine we would have to pay for
such "rights." The implications of this are obviously unappealing and an
obvious danger to individual freedom. The problem of access associated with
the idea of privatising the roads can only be avoided by having a "right of
passage" encoded into the "general libertarian law code." This would mean that
road owners would be required, by law, to let anyone use them. But where are
"absolute" property rights in this case? Are the owners of roads not to have
the same rights as other owners? And if "right of passage" is enforced, what
would this mean for road owners when people sue them for car-pollution related
illnesses? (The right of those injured by pollution to sue polluters is the
main way "anarcho"-capitalists propose to protect the environment. See
sections [E.2](secE2.html) and [E.3](secE3.html)). It is unlikely that those
wishing to bring suit could find, never mind sue, the millions of individual
car owners who could have potentially caused their illness. Hence the road-
owners would be sued for letting polluting (or unsafe) cars onto "their"
roads. The road-owners would therefore desire to restrict pollution levels by
restricting the right to use their property, and so would resist the "right of
passage" as an "attack" on their "absolute" property rights. If the road-
owners got their way (which would be highly likely given the need for
"absolute" property rights and is suggested by the variable pricing way to
avoid traffic jams mentioned above) and were able to control who used their
property, freedom to travel would be **very** restricted and limited to those
whom the owner considered "desirable." Indeed, Murray Rothbard supports such a
regime (_"In the free [sic!] society, they [travellers] would, in the first
instance, have the right to travel only on those streets whose owners agree to
have them there"_ [**The Ethics of Liberty**, p. 119]). The threat to liberty
in such a system is obvious -- to all but Rothbard and other right-
libertarians, of course.

To take another example, let us consider the privatisation of parks, streets
and other public areas. Currently, individuals can use these areas to hold
political demonstrations, hand out leaflets, picket and so on. However, under
"anarcho"-capitalism the owners of such property can restrict such liberties
if they desire, calling such activities "initiation of force" (although they
cannot explain how speaking your mind is an example of "force"). Therefore,
freedom of speech, assembly and a host of other liberties we take for granted
would be reduced (if not eliminated) under a right-"libertarian" regime. Or,
taking the case of pickets and other forms of social struggle, its clear that
privatising "the commons" would only benefit the bosses. Strikers or other
activists picketing or handing out leaflets in shopping centre's are quickly
ejected by private security even today. Think about how much worse it would
become under "anarcho"-capitalism when the whole world becomes a series of
malls -- it would be impossible to hold a picket when the owner of the
pavement objects, for example (as Rothbard himself argues, **Op. Cit.**, p.
132) and if the owner of the pavement also happens to be the boss being
picketed, then workers' rights would be zero. Perhaps we could also see
capitalists suing working class organisations for littering their property if
they do hand out leaflets (so placing even greater stress on limited
resources).

The I.W.W. went down in history for its rigorous defence of freedom of speech
because of its rightly famous "free speech" fights in numerous American cities
and towns. Repression was inflicted upon wobblies who joined the struggle by
"private citizens," but in the end the I.W.W. won. Consider the case under
"anarcho"-capitalism. The wobblies would have been "criminal aggressors" as
the owners of the streets have refused to allow "undesirables" to use them to
argue their case. If they refused to acknowledge the decree of the property
owners, private cops would have taken them away. Given that those who
controlled city government in the historical example were the wealthiest
citizens in town, its likely that the same people would have been involved in
the fictional ("anarcho"-capitalist) account. Is it a good thing that in the
real account the wobblies are hailed as heroes of freedom but in the fictional
one they are "criminal aggressors"? Does converting public spaces into private
property **really** stop restrictions on free speech being a bad thing?

Of course, Rothbard (and other right-libertarians) are aware that
privatisation will not remove restrictions on freedom of speech, association
and so on (while, at the same time, trying to portray themselves as supporters
of such liberties!). However, for right-libertarians such restrictions are of
no consequence. As Rothbard argues, any _"prohibitions would not be state
imposed, but would simply be requirements for residence or for use of some
person's or community's land area."_ [**Nations by Consent**, p. 85] Thus we
yet again see the blindness of right-libertarians to the commonality between
private property and the state. The state also maintains that submitting to
its authority is the requirement for taking up residence in its territory (see
also [section 2.3](append132.html#secf23) for more on this). As Benjamin
Tucker noted, the state can be defined as (in part) _"the assumption of sole
authority over a given area and all within it."_ [**The Individualist
Anarchists**, p. 24] If the property owners can determine "prohibitions" (i.e.
laws and rules) for those who use the property then they are the _"sole
authority over a given area and all within it,"_ i.e. a state. Thus
privatising "the commons" means subjecting the non-property owners to the
rules and laws of the property owners -- in effect, privatising the state and
turning the world into a series of Monarchies and oligarchies without the
pretence of democracy and democratic rights.

These examples can hardly be said to be increasing liberty for society as a
whole, although "anarcho" capitalists seem to think they would. So far from
**increasing** liberty for all, then, privatising the commons would only
increase it for the ruling elite, by giving them yet another monopoly from
which to collect income and exercise their power over. It would **reduce**
freedom for everyone else. As Peter Marshall notes, _"[i]n the name of
freedom, the anarcho-capitalists would like to turn public spaces into private
property, but freedom does not flourish behind high fences protected by
private companies but expands in the open air when it is enjoyed by all"_
[**Demanding the Impossible**, p. 564].

Little wonder Proudhon argued that _"if the public highway is nothing but an
accessory of private property; if the communal lands are converted into
private property; if the public domain, in short, is guarded, exploited,
leased, and sold like private property -- what remains for the proletaire? Of
what advantage is it to him that society has left the state of war to enter
the regime of police?"_ [**System of Economic Contradictions**, p. 371]

[‹ 4 What is the right-libertarian position on private
property?](/afaq/append134.html "Go to previous page" )
[up](/afaq/append13.html "Go to parent page" ) [6 Is "anarcho"-capitalism
against the state? ›](/afaq/append136.html "Go to next page" )

==> anarchism_15.3.orig.tar.gz: afaq-15.3/markdown/append135.md <==
# 5 Will privatising "the commons" increase liberty?

"Anarcho"-capitalists aim for a situation in which _"no land areas, no square
footage in the world shall remain 'public,'"_ in other words **everything**
will be _"privatised."_ [Murray Rothbard, **Nations by Consent** , p. 84] They
claim that privatising "the commons" (e.g. roads, parks, etc.) which are now
freely available to all will increase liberty. Is this true? We have shown
before why the claim that privatisation can protect the environment is highly
implausible (see section [E.2](secE2.md)). Here we will concern ourselves
with private ownership of commonly used "property" which we all take for
granted and pay for with taxes.

Its clear from even a brief consideration of a hypothetical society based on
"privatised" roads (as suggested by Murray Rothbard in **For a New Liberty** ,
pp. 202-203 and David Friedman in **The Machinery of Freedom** , pp. 98-101)
that the only increase of liberty will be for the ruling elite. As
"anarcho"-capitalism is based on paying for what one uses, privatisation of
roads would require some method of tracking individuals to ensure that they
pay for the roads they use. In the UK, for example, during the 1980s the
British Tory government looked into the idea of toll-based motorways.
Obviously having toll-booths on motorways would hinder their use and restrict
"freedom," and so they came up with the idea of tracking cars by satellite.
Every vehicle would have a tracking device installed in it and a satellite
would record where people went and which roads they used. They would then be
sent a bill or have their bank balances debited based on this information (in
the fascist city-state/company town of Singapore such a scheme **has** been
introduced).

If we extrapolate from this example to a system of **fully** privatised
"commons," it would clearly require all individuals to have tracking devices
on them so they could be properly billed for use of roads, pavements, etc.
Obviously being tracked by private firms would be a serious threat to
individual liberty. Another, less costly, option would be for private guards
to randomly stop and question car-owners and individuals to make sure they had
paid for the use of the road or pavement in question. "Parasites" would be
arrested and fined or locked up. Again, however, being stopped and questioned
by uniformed individuals has more in common with police states than liberty.
Toll-boothing **every** street would be highly unfeasible due to the costs
involved and difficulties for use that it implies. Thus the idea of
privatising roads and charging drivers to gain access seems impractical at
best and distinctly freedom endangering if implemented at worse.

Of course, the option of owners letting users have free access to the roads
and pavements they construct and run would be difficult for a profit-based
company. No one could make a profit in that case. If companies paid to
construct roads for their customers/employees to use, they would be
financially hindered in competition with other companies that did not, and
thus would be unlikely to do so. If they restricted use purely to their own
customers, the tracking problem appears again.

Some may object that this picture of extensive surveillance of individuals
would not occur or be impossible. However, Murray Rothbard (in a slightly
different context) argued that technology would be available to collate
information about individuals. He argued that _"[i]t should be pointed out
that modern technology makes even more feasible the collection and
dissemination of information about people's credit ratings and records of
keeping or violating their contracts or arbitration agreements. Presumably, an
anarchist [sic!] society would see the expansion of this sort of dissemination
of data."_ [ _"Society Without A State"_ , in **Nomos XIX** , Pennock and
Chapman (eds.), p. 199] So, perhaps, with the total privatisation of society
we would also see the rise of private Big Brothers, collecting information
about individuals for use by property owners. The example of the **Economic
League** (a British company who provided the "service" of tracking the
political affiliations and activities of workers for employers) springs to
mind.

And, of course, these privatisation suggestions ignore differences in income
and market power. If, for example, variable pricing is used to discourage road
use at times of peak demand (to eliminate traffic jams at rush-hour) as is
suggested both by Murray Rothbard and David Friedman, then the rich will have
far more "freedom" to travel than the rest of the population. And we may even
see people having to go into debt just to get to work or move to look for
work.

Which raises another problem with notion of total privatisation, the problem
that it implies the end of freedom of travel. Unless you get permission or
(and this seems more likely) pay for access, you will not be able to travel
**anywhere.** As Rothbard **himself** makes clear, "anarcho"-capitalism means
the end of the right to roam or even travel. He states that _"it became clear
to me that a totally privatised country would not have open borders at all. If
every piece of land in a country were owned . . . no immigrant could enter
there unless invited to enter and allowed to rent, or purchase, property."_ [
**Nations by Consent** , p. 84] What happens to those who cannot **afford** to
pay for access is not addressed (perhaps, being unable to exit a given
capitalist's land they will become bonded labourers? Or be imprisoned and used
to undercut workers' wages via prison labour? Perhaps they will just be shot
as trespassers? Who can tell?). Nor is it addressed how this situation
actually **increases** freedom. For Rothbard, a _"totally privatised country
would be as closed as the particular inhabitants and property owners [ **not**
the same thing, we must point out] desire. It seems clear, then, that the
regime of open borders that exists **de facto** in the US really amounts to a
compulsory opening by the central state. . . and does not genuinely reflect
the wishes of the proprietors."_ [ **Op. Cit.** , p. 85] Of course, the wishes
of **non** -proprietors (the vast majority) do not matter in the slightest.
Thus, it is clear, that with the privatisation of "the commons" the right to
roam, to travel, would become a privilege, subject to the laws and rules of
the property owners. This can hardly be said to **increase** freedom for
anyone bar the capitalist class.

Rothbard acknowledges that _"in a fully privatised world, access rights would
obviously be a crucial part of land ownership."_ [ **Nations by Consent** , p.
86] Given that there is no free lunch, we can imagine we would have to pay for
such "rights." The implications of this are obviously unappealing and an
obvious danger to individual freedom. The problem of access associated with
the idea of privatising the roads can only be avoided by having a "right of
passage" encoded into the "general libertarian law code." This would mean that
road owners would be required, by law, to let anyone use them. But where are
"absolute" property rights in this case? Are the owners of roads not to have
the same rights as other owners? And if "right of passage" is enforced, what
would this mean for road owners when people sue them for car-pollution related
illnesses? (The right of those injured by pollution to sue polluters is the
main way "anarcho"-capitalists propose to protect the environment. See
sections [E.2](secE2.md) and [E.3](secE3.md)). It is unlikely that those
wishing to bring suit could find, never mind sue, the millions of individual
car owners who could have potentially caused their illness. Hence the road-
owners would be sued for letting polluting (or unsafe) cars onto "their"
roads. The road-owners would therefore desire to restrict pollution levels by
restricting the right to use their property, and so would resist the "right of
passage" as an "attack" on their "absolute" property rights. If the road-
owners got their way (which would be highly likely given the need for
"absolute" property rights and is suggested by the variable pricing way to
avoid traffic jams mentioned above) and were able to control who used their
property, freedom to travel would be **very** restricted and limited to those
whom the owner considered "desirable." Indeed, Murray Rothbard supports such a
regime ( _"In the free [sic!] society, they [travellers] would, in the first
instance, have the right to travel only on those streets whose owners agree to
have them there"_ [ **The Ethics of Liberty** , p. 119]). The threat to
liberty in such a system is obvious -- to all but Rothbard and other right-
libertarians, of course.

To take another example, let us consider the privatisation of parks, streets
and other public areas. Currently, individuals can use these areas to hold
political demonstrations, hand out leaflets, picket and so on. However, under
"anarcho"-capitalism the owners of such property can restrict such liberties
if they desire, calling such activities "initiation of force" (although they
cannot explain how speaking your mind is an example of "force"). Therefore,
freedom of speech, assembly and a host of other liberties we take for granted
would be reduced (if not eliminated) under a right-"libertarian" regime. Or,
taking the case of pickets and other forms of social struggle, its clear that
privatising "the commons" would only benefit the bosses. Strikers or other
activists picketing or handing out leaflets in shopping centre's are quickly
ejected by private security even today. Think about how much worse it would
become under "anarcho"-capitalism when the whole world becomes a series of
malls -- it would be impossible to hold a picket when the owner of the
pavement objects, for example (as Rothbard himself argues, **Op. Cit.** , p.
132) and if the owner of the pavement also happens to be the boss being
picketed, then workers' rights would be zero. Perhaps we could also see
capitalists suing working class organisations for littering their property if
they do hand out leaflets (so placing even greater stress on limited
resources).

The I.W.W. went down in history for its rigorous defence of freedom of speech
because of its rightly famous "free speech" fights in numerous American cities
and towns. Repression was inflicted upon wobblies who joined the struggle by
"private citizens," but in the end the I.W.W. won. Consider the case under
"anarcho"-capitalism. The wobblies would have been "criminal aggressors" as
the owners of the streets have refused to allow "undesirables" to use them to
argue their case. If they refused to acknowledge the decree of the property
owners, private cops would have taken them away. Given that those who
controlled city government in the historical example were the wealthiest
citizens in town, its likely that the same people would have been involved in
the fictional ("anarcho"-capitalist) account. Is it a good thing that in the
real account the wobblies are hailed as heroes of freedom but in the fictional
one they are "criminal aggressors"? Does converting public spaces into private
property **really** stop restrictions on free speech being a bad thing?

Of course, Rothbard (and other right-libertarians) are aware that
privatisation will not remove restrictions on freedom of speech, association
and so on (while, at the same time, trying to portray themselves as supporters
of such liberties!). However, for right-libertarians such restrictions are of
no consequence. As Rothbard argues, any _"prohibitions would not be state
imposed, but would simply be requirements for residence or for use of some
person's or community's land area."_ [ **Nations by Consent** , p. 85] Thus we
yet again see the blindness of right-libertarians to the commonality between
private property and the state. The state also maintains that submitting to
its authority is the requirement for taking up residence in its territory (see
also [section 2.3](append132.md#secf23) for more on this). As Benjamin
Tucker noted, the state can be defined as (in part) _"the assumption of sole
authority over a given area and all within it."_ [ **The Individualist
Anarchists** , p. 24] If the property owners can determine "prohibitions"
(i.e. laws and rules) for those who use the property then they are the _"sole
authority over a given area and all within it,"_ i.e. a state. Thus
privatising "the commons" means subjecting the non-property owners to the
rules and laws of the property owners -- in effect, privatising the state and
turning the world into a series of Monarchies and oligarchies without the
pretence of democracy and democratic rights.

These examples can hardly be said to be increasing liberty for society as a
whole, although "anarcho" capitalists seem to think they would. So far from
**increasing** liberty for all, then, privatising the commons would only
increase it for the ruling elite, by giving them yet another monopoly from
which to collect income and exercise their power over. It would **reduce**
freedom for everyone else. As Peter Marshall notes, _"[i]n the name of
freedom, the anarcho-capitalists would like to turn public spaces into private
property, but freedom does not flourish behind high fences protected by
private companies but expands in the open air when it is enjoyed by all"_ [
**Demanding the Impossible** , p. 564].

Little wonder Proudhon argued that _"if the public highway is nothing but an
accessory of private property; if the communal lands are converted into
private property; if the public domain, in short, is guarded, exploited,
leased, and sold like private property -- what remains for the proletaire? Of
what advantage is it to him that society has left the state of war to enter
the regime of police?"_ [ **System of Economic Contradictions** , p. 371]

[‹ 4 What is the right-libertarian position on private
property?](append134.md "Go to previous page") [up](append13.md "Go to
parent page") [6 Is "anarcho"-capitalism against the state? ›](append136.md
"Go to next page")
